"use strict";

const path = require('path');
const {
  existsSync
} = require('fs');
const {
  execSync
} = require("child_process");
const {
  deleteFile
} = require('../FileAndFolderOperations/deleteFile');
const {
  getClonedDirPath,
  getDeleteDirPath,
  unzipFolder
} = require('./HelperFunctions/helpers');
const {
  getRepoName
} = require("../GitActions/gitActions");
const {
  Logger
} = require('..//Logger/Logger');
const {
  removeFolder
} = require("../FileAndFolderOperations/removeFolder");
const {
  executeSynchronizedCommands
} = require('../General/executeSyncCommands');
const {
  getLibraryInstalledLocation
} = require('../General/getLibraryInstalledLocation');
const {
  accessToken,
  endPoint,
  commonLinterRepoZip
} = require('../../../jsonUtils/commonLinterRepoDetails');
/**
 * @function cloneViaCdt - Using the "clint development tool" clones the common linter_configuration repo into precommit library
 * @returns {boolean} - indicating the success or failure of the cloning process
 */

function cloneViaCdt() {
  removeFolder(getDeleteDirPath());
  let pathOfFolderToUnzip = path.join(getLibraryInstalledLocation(), commonLinterRepoZip);
  let pathWhereFolderShouldBeExtracted = path.join(getLibraryInstalledLocation());
  const commandToCloneCommonConfigRepo = `curl -O -L -H "Content-Type: application/java-archive" -H "PRIVATE-TOKEN: ${accessToken}" "${endPoint}"`;
  let isCommonConfigurationClonedSuccessfully = false;
  try {
    if (!existsSync(pathOfFolderToUnzip)) {
      isCommonConfigurationClonedSuccessfully = executeSynchronizedCommands(execSync, [commandToCloneCommonConfigRepo, {
        cwd: getClonedDirPath()
      }], `Lint Configuration Cloned Successfully - ${getRepoName() || 'common'}`, 'Could not clone the linters common repo', false, true);
    } else {
      deleteFile(pathOfFolderToUnzip);
      isCommonConfigurationClonedSuccessfully = executeSynchronizedCommands(execSync, [commandToCloneCommonConfigRepo, {
        cwd: getClonedDirPath()
      }], `Lint Configuration Cloned Successfully - ${getRepoName() || 'common'}`, 'Could not clone the linters common repo', false, true);
    }
  } catch (error) {
    Logger.log(Logger.FAILURE_TYPE, error);
    Logger.log(Logger.FAILURE_TYPE, 'Error occured while checking if linter configuration zip file exists');
  }
  if (isCommonConfigurationClonedSuccessfully) {
    return unzipFolder(pathOfFolderToUnzip, pathWhereFolderShouldBeExtracted);
  }
  return false;
}
module.exports = {
  cloneViaCdt
};