"use strict";

const {
  Logger
} = require('../Logger/Logger');

/**
 * @function filterFiles - removes certain files from set of source files
 * @param {Array} arrayOfFilesToBeFiltered - array of files which must be filtered 
 * @param {Array} filesToBeRemoved - array of files that need to be removed
 * @param {boolean} isConfigFileNeedToBeRemoved - indicating whether eslint config file should be removed or not
 * @returns {Array} - containing the resultant set of files after filtering
 */
function filterFiles(arrayOfFilesToBeFiltered, filesToBeRemoved, isConfigFileNeedToBeRemoved = false) {
  if (filesToBeRemoved.length !== 0) {
    if (isConfigFileNeedToBeRemoved) {
      arrayOfFilesToBeFiltered.filter(file => {
        let isConfigFileModified = filesToBeRemoved.some(fileToBeRemoved => file.includes(fileToBeRemoved));
        if (isConfigFileModified) {
          Logger.log(Logger.INFO_TYPE, 'The eslint config file should not be modified locally. Update the file in the common repo for linters.');
          Logger.log(Logger.FAILURE_TYPE, 'Kindly revert the changes in eslint config file and commit the rest.');
          process.exit(1);
        }
      });
    }
    let filteredArrayofFilesWithoutConfigFile = arrayOfFilesToBeFiltered.filter(file => {
      let isFileToBeRemovedPresent = filesToBeRemoved.some(fileToBeRemoved => file.includes(fileToBeRemoved));
      if (!isFileToBeRemovedPresent) {
        return true;
      } else {
        return false;
      }
    });
    return filteredArrayofFilesWithoutConfigFile;
  } else if (filesToBeRemoved.length === 0) {
    return arrayOfFilesToBeFiltered;
  }
}
module.exports = {
  filterFiles
};