"use strict";

/* eslint-disable no-console */
const os = require('os');
const fs = require('fs');
const {
  Logger
} = require('../Logger/Logger');

/**
 * @function grantExecutionPermission - grnats execution permission to set of files
 * @param {Array} filesToWhichExecutionPermissionToBeGiven 
 * @returns {boolean} - indicating whether execution permission given to all provided files
 * @note - this method gives execution permission only if operating system is either Mac or Linux
 */
function grantExecutionPermission(filesToWhichExecutionPermissionToBeGiven) {
  let ostype = os.type();
  if (ostype === 'Darwin' || ostype === 'Linux') {
    let filesThatWereGivenExecutionPermission = filesToWhichExecutionPermissionToBeGiven.filter(file => {
      try {
        fs.chmodSync(file, '755');
        Logger.log(Logger.SUCCESS_TYPE, `execution permission given to ${file}`);
        return true;
      } catch (error) {
        Logger.log(Logger.FAILURE_TYPE, error);
        Logger.log(Logger.FAILURE_TYPE, `Unable to give execution permission to ${file}`);
        return false;
      }
    });
    return filesThatWereGivenExecutionPermission.length === filesToWhichExecutionPermissionToBeGiven.length ? true : false;
  } else {
    return true;
  }
}
module.exports = grantExecutionPermission;