"use strict";

const {
  Logger
} = require('../Logger/Logger');

/**
 * @function executeSynchronizedCommands - a wrapper function to execute synchronized command within try catch and return either the result of command or boolean value indicating the success or failure of command execution
 * @param {Function} command - function to be executed
 * @param {Array} commandArgs - arguments to be passed to the function to be executed
 * @param {string} successMessage - success message to should be logged on successful execution of the provided function
 * @param {string} errorMessage - failure message to be logged when the given function execution fails
 * @param {boolean} shouldCommandResultBeReturned - indicates if output of command to be returned
 * @param {boolean} shouldReturnBooleanValue - indicates if boolean value corresponding to command execution output be returned
 * @returns {boolean | string} - returns either a boolean indicating the success or failure of the command executed or the result returned by the executed command 
 */
function executeSynchronizedCommands(command, commandArgs, successMessage = '', errorMessage = '', shouldCommandResultBeReturned = false, shouldReturnBooleanValue = false) {
  try {
    if (shouldCommandResultBeReturned) {
      return command(...commandArgs);
    } else if (!shouldCommandResultBeReturned) {
      command(...commandArgs);
    }
    if (successMessage.trim() !== '') {
      Logger.log(Logger.SUCCESS_TYPE, successMessage);
    }
    if (shouldReturnBooleanValue) {
      return true;
    }
  } catch (error) {
    Logger.log(Logger.FAILURE_TYPE, error);
    Logger.log(Logger.FAILURE_TYPE, errorMessage);
    if (shouldReturnBooleanValue) {
      return false;
    }
  }
}
module.exports = {
  executeSynchronizedCommands
};